@@ -64,8 +64,6 @@ if __name__ == '__main__':
             os.system("cp -R cinnamon/light-assets %s" % version_folder)
             os.system("cp cinnamon/mint-y-thumbnail.png %s" % os.path.join(version_folder, "thumbnail.png"))
             os.system("cp cinnamon/cinnamon.css %s" % version_folder)
-            # XFCE-Notify
-            os.system("cp -R xfce-notify-4.0 %s" % dest_folder)
             # XFWM
             os.system("cp -R xfwm4 %s" % dest_folder)
 
@@ -86,12 +84,6 @@ if __name__ == '__main__':
             os.system("cp gtk-3.0/gtk-darker.css %s" % os.path.join(version_folder, "gtk.css"))
             os.system("cp gtk-3.0/gtk-dark.css %s" % version_folder)
             os.system("cp gtk-3.0/thumbnail.png %s" % version_folder)
-            # XFCE-Notify
-            os.system("cp -R xfce-notify-4.0 %s" % dest_folder)
-            # XFWM
-            os.system("rm -rf %s" % os.path.join(dest_folder, "xfwm4"))
-            os.system("cp -R xfwm4-dark %s" % dest_folder)
-            os.system("mv %s %s" % (os.path.join(dest_folder, "xfwm4-dark"), os.path.join(dest_folder, "xfwm4")))
 
         elif variation == "Mint-Y-Dark":
             print("    Building Mint-Y-Dark")
@@ -123,8 +115,6 @@ if __name__ == '__main__':
             os.system("cp -R cinnamon/dark-assets %s" % version_folder)
             os.system("cp cinnamon/mint-y-dark-thumbnail.png %s" % os.path.join(version_folder, "thumbnail.png"))
             os.system("cp cinnamon/cinnamon-dark.css %s" % os.path.join(version_folder, "cinnamon.css"))
-            # XFCE-Notify
-            os.system("cp -R xfce-notify-4.0 %s" % dest_folder)
             # XFWM
             os.system("rm -rf %s" % os.path.join(dest_folder, "xfwm4"))
             os.system("cp -R xfwm4-dark %s" % dest_folder)
